# Examples

Code examples below are located in `examples` directory.


## Basic usage

```python
--8<-- "examples/usage.py"
```


## Driver demo

```python
--8<-- "examples/demo.py"
```

## Position control

```python
--8<-- "src/odrive_can/examples/position_control.py"
```

## Velocity control

```python
--8<-- "src/odrive_can/examples/velocity_control.py"
```
